@@ -20,7 +20,6 @@ class DataTransmission:
         self.api_base_url = api_base_url
         self.iv = iv
         self.key = key
-        self.session = aiohttp.ClientSession()
 
     async def request(
         self,
@@ -37,12 +36,16 @@ class DataTransmission:
             data['uuid'] = get_uuid()
 
         files = kwargs.pop('files', {})
-        files['hash_file'] = s2b(self.hash_data(data))
+        formdata = aiohttp.FormData()
+        formdata.add_field('hash_file', s2b(self.hash_data(data)))
 
-        async with self.session.request(
+        for k, v in files.items():
+            formdata.add_field(k, v)
+
+        async with aiohttp.request(
             method=method,
             url=url,
-            files=files,
+            data=formdata,
             **kwargs
         ) as response:
             if self.response_is_text(response):
