@@ -58,12 +58,14 @@ def validate(
             result = await validate_and_exec(
                 rules,
                 request_data,
+                parse_json,
+                use_dict,
                 view_func,
                 (rq, *args),
                 kwargs
             )
 
-            if result == False:
+            if result is None:
                 return _error_422
             return result
         return wrapped_view
